@@ -33,31 +33,36 @@ sub startup : Test(startup => 2)
         or $self->FAIL_ALL('cannot create object');
 }
 
-sub accessors : Test(6)
+sub accessors : Test(7)
 {
     my $self = shift;
 
     # put your account details here
     my $email = 'email@gmail.com';
     my $password = 'password';
-    my $token = $email . '++INR';
+    my $developerToken = $email . '++INR';
+    my $applicationToken = 'ZYXwvu-TSR123_456ABCDE';
+    
 
     if ($self->{'sandbox'}) {
         $email = $self->{'email'};
         $password = $self->{'password'};
-        $token = $self->{'token'};
+        $developerToken = $self->{'developerToken'};
+        $applicationToken = 'ZYXwvu-TSR123_456ABCDE';
     }   
 
     $self->{'obj'}->email($email)
         ->password($password)
-        ->token($token)
+        ->developerToken($developerToken)
+        ->applicationToken($applicationToken)
         ->use_sandbox(1)
         ->clientEmail('client_1' . '+' . $email)
     ;
 
     ok ($self->{'obj'}->email eq $email, 'email');
     ok ($self->{'obj'}->password eq $password, 'password');
-    ok ($self->{'obj'}->token eq $token, 'token');
+    ok ($self->{'obj'}->developerToken eq $developerToken, 'developerToken');
+    ok ($self->{'obj'}->applicationToken eq $applicationToken, 'applicationToken');
     ok ($self->{'obj'}->use_sandbox == 1, 'use_sandbox');
     ok ($self->{'obj'}->clientEmail eq 'client_1' . '+' . $email, 'clientEmail');
     ok ($self->{'obj'}->debug == 0, 'debug');
